import { Query } from "queric";
import Socket from './Socket';
/**
 * This function can be used to check the access with the token payload of a socket.
 * You can set that the token payload has to match with a queric query.
 * @example
 * access: $tokenPayloadMatches({age: {$gt: 18}})
 * @param query
 */
export declare function $tokenPayloadMatches<T>(query: Query<T>): (socket: Socket) => boolean;
/**
 * This function can be used to check the access with the handshake attachment of a socket.
 * You can set that the handshake attachment has to match with a queric query.
 * @example
 * access: $handshakeAttachmentMatches({device: 'MO'})
 * @param query
 */
export declare function $handshakeAttachmentMatches<T>(query: Query<T>): (socket: Socket) => boolean;
/**
 * This function can be used to check the access with the socket attachment.
 * You can set that the socket attachment has to match with a queric query.
 * @example
 * access: $socketAttachmentMatches({code: 2313})
 * @param query
 */
export declare function $socketAttachmentMatches<T>(query: Query<T>): (socket: Socket) => boolean;
/**
 * This function can be used to check the access with the token user id of a socket.
 * You can set that the token user-id has to match with a specific string or number.
 * @example
 * access: [$userId('luca'),$userId(221,false)]
 * @param id
 * @param strictTypeCheck
 * indicates if the type should also be checked (number and string).
 */
export declare function $userId(id: number | string, strictTypeCheck?: boolean): import("../main/access/accessOptions").UserIdCheck;
