export interface UserGroupsConfig {
    /**
     * A socket that is not authenticated belongs to the default user group.
     * In this property, you can define the name of these user group.
     * @example
     * default: 'guest'
     */
    default?: string;
    /**
     * The auth object contains all user groups that can only be reached
     * if the socket is authenticated.
     * @example
     * auth: {
     *      user: {
     *           panelDisplayName: 'User'
     *      },
     * },
     */
    auth?: Record<string, AuthUserGroupConfig>;
}
export interface AuthUserGroupConfig {
    /**
     * This property is only for advanced use cases.
     * Here you can set if this user group has panel access automatically.
     */
    panelAccess?: boolean;
    /**
     * Here you can define the name of the user group
     * that will be displayed in the zation panel.
     */
    panelDisplayName?: string;
}
